import pytest
import os
from swarmauri_standard.llms.CohereModel import CohereModel as LLM
from swarmauri_standard.conversations.Conversation import Conversation

from swarmauri_standard.messages.HumanMessage import HumanMessage
from swarmauri_standard.messages.SystemMessage import SystemMessage


@pytest.fixture(scope="module")
def cohere_model():
    API_KEY = os.getenv("COHERE_API_KEY")
    if not API_KEY:
        pytest.skip("Skipping due to environment variable not set")
    llm = LLM(api_key=API_KEY)
    return llm


@pytest.mark.xfail(reason="This test is expected to fail")
@pytest.mark.acceptance
def test_nonpreamble_system_context(cohere_model):
    model = cohere_model
    conversation = Conversation()

    # Say hi
    input_data = "Hi"
    human_message = HumanMessage(content=input_data)
    conversation.add_message(human_message)

    # Get Prediction
    model.predict(conversation=conversation)

    # Give System Context
    system_context = 'You only respond with the following phrase, "Jeff"'
    human_message = SystemMessage(content=system_context)
    conversation.add_message(human_message)

    # Prompt
    input_data = "Hello Again."
    human_message = HumanMessage(content=input_data)
    conversation.add_message(human_message)

    model.predict(conversation=conversation, temperature=0)
    prediction = conversation.get_last().content
    assert "Jeff" in prediction
